View source: R/40-priority_queue-methods.R
| as.list.priority_queue | R Documentation |
Returns queue entries as a plain list of records with fields value and
priority, in queue sequence order.
## S3 method for class 'priority_queue'
as.list(x, ..., drop_meta = FALSE)
x |
A |
... |
Unused. |
drop_meta |
Logical scalar. When |
Each returned entry is a record with fields value and priority.
Entry names (when present) are preserved on the returned list.
A plain list of queue entry records (drop_meta = FALSE) or payload
values (drop_meta = TRUE).
q <- priority_queue("a", "b", priorities = c(2, 1))
as.list(q)
as.list(q, drop_meta = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.