Returns the largest key currently present in the ordered sequence.
Examples
x <- ordered_sequence("a", "b", keys = c(2, 1))
max_key(x)
#> [1] 2
max_key(ordered_sequence())
#> NULL
Returns the largest key currently present in the ordered sequence.
x <- ordered_sequence("a", "b", keys = c(2, 1))
max_key(x)
#> [1] 2
max_key(ordered_sequence())
#> NULL