tree_from: Build a Structural Tree from a Vector or List

View source: R/30-api-flexseq-tree-from.R

tree_fromR Documentation

Build a Structural Tree from a Vector or List

Description

Build a Structural Tree from a Vector or List

Usage

tree_from(x, monoids = NULL)

Arguments

x

Elements to insert.

monoids

Optional named list of measure_monoid objects.

Value

A finger tree with cached measures for all monoids. If x has names, they are used for name-based indexing and must be complete (no missing/empty names) and unique.


Immutables documentation built on April 29, 2026, 1:06 a.m.