View source: R/30-api-flexseq-validate.R
| validate_name_state | R Documentation |
Checks that trees are either fully unnamed or fully named with unique, non-empty names.
validate_name_state(t)
t |
FingerTree. |
Intended for debugging and tests, not hot runtime paths.
TRUE invisibly; errors if name invariants are violated.
x <- as_flexseq(setNames(as.list(letters[1:4]), letters[1:4]))
validate_name_state(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.