View source: R/60-interval_index-query-api.R
| peek_point | R Documentation |
Peek First Interval Matching a Point
peek_point(
x,
point,
bounds = NULL,
match_at = c("interval", "start", "end", "either")
)
x |
An |
point |
Query point. |
bounds |
Optional boundary override. One of |
match_at |
How the query point is matched against each entry. One of
|
Returns the first match in canonical interval order. Use peek_all_point() to
retrieve all matches as an interval_index slice.
The payload value from the first match, or NULL on no match.
ix <- interval_index("a", "b", "c", start = c(1, 2, 4), end = c(3, 2, 5))
peek_point(ix, 2)
# Boundary override at an endpoint
edge <- interval_index("a", start = 1, end = 3, default_query_bounds = "[)")
peek_point(edge, 3) # default "[)": no match at right endpoint
peek_point(edge, 3, bounds = "[]") # closed bounds: endpoint matches
# Coordinate-equality modes (bounds irrelevant)
peek_point(ix, 2, match_at = "start") # entry starting at 2
peek_point(ix, 3, match_at = "end") # entry ending at 3
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.