View source: R/30-api-flexseq-tree-from.R
| tree_from | R Documentation |
Build a Structural Tree from a Vector or List
tree_from(x, monoids = NULL)
x |
Elements to insert. |
monoids |
Optional named list of |
A finger tree with cached measures for all monoids.
If x has names, they are used for name-based indexing and must be
complete (no missing/empty names) and unique.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.